#include <hidef.h>					// common defines and macros
#include <mc9s12hy64.h>				// derivative information
#include "cpu.h"						// CPU routines


/**********************************************************
*	mcu_init
*
*	Setup clock module for PLL Bypass, External.  For DEMOHY64
*	using 8MH XTAL, 
*	Core Clk - 8MHz, Bus Clk - 4MHz
**********************************************************/
void mcu_init(void){

	PTTRR = 0x30;						// TIM0-C7, C6 routed to Port R 
//	ECLKCTL_NECLK = 0;				// turn on ECLK output 
	DisableInterrupts;				// disable interrupts during configuration
	CPMU_PEE_4MHz();					// init clock module 4MHz bus clock
	Init_Timer1();						// init timer1
	Configure_Ports();	
	init_atd();							// en ATD_CH0 
	EnableInterrupts;
	
}

/**********************************************************
*	CPMU_PBE
*
*	Setup clock module for PLL Bypass, External.  For DEMOHY64
*	using 8MH XTAL, 
*	Core Clk - 8MHz, Bus Clk - 4MHz
**********************************************************/
void CPMU_PBE(void){
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC);			// wait for ext osc to stabilize
	CPMUCLKS_PLLSEL = 0;				// select ext oscillator
}

/**********************************************************
*	CPMU_PEE_8MHz
*
*	Setup clock module for PLL Engaged using externals XTAL
*	For DEMOHY64 w/ 8MHz XTAL - 
*	VCOCLK - 64MHz, Core Clk - 16MHz, Bus Clk - 8MHz
**********************************************************/
void CPMU_PEE_8MHz(void){

	CPMUSYNR = 0x01;					// fVCO = 32MHz
	CPMUREFDIV = 0x80;				// OSC input is 8MHz
	CPMUPOSTDIV = 0x01;				// core clk - 16MHz, bus clk - 8MHz
	
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC || !CPMUFLG_LOCK);
											// wait for ext osc to stabilize and pll to lock
	CPMUFLG = 0xFF;					// clear CMPMU int flags - not needed but good practice
}

/**********************************************************
*	CPMU_PEE_4MHz
*
*	Setup clock module for PLL Engaged using externals XTAL
*	For DEMOHY64 w/ 8MHz XTAL - 
*	VCOCLK - 32MHz, Core Clk - 8MHz, Bus Clk - 4MHz
**********************************************************/
void CPMU_PEE_4MHz(void){

	CPMUSYNR = 0x01;					// fVCO = 32MHz
	CPMUREFDIV = 0x80;				// OSC input is 8MHz
	CPMUPOSTDIV = 0x03;				// core clk - 8MHz, bus clk - 4MHz
	
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC || !CPMUFLG_LOCK);
											// wait for ext osc to stabilize and pll to lock
	CPMUFLG = 0xFF;					// clear CMPMU int flags - not needed but good practice
}											// bus clk = 4MHz

/**********************************************************
*	init_tim0
*
*	Init TIM0 as free-running @ bus clk rate.  Config C7, C6 
*	as output compare
*
**********************************************************/
void init_tim0_ch6(void){

	TIM0_TIOS = 0x40;					// configure C6 as output compare
	TIM0_OC7M = 0x40;					// en C6 output on compare
	TIM0_TCTL1 = 0x10;				// C6 toggle on compare
	TIM0_TSCR2_PR = 0x7;				// timer runs at bus clk rate div 128

	TIM0_TC6 = BLINK_DELAY;			// load timer channel count
	TIM0_TFLG1_C6F = 1;				// clear C6 flag
	TIM0_TIE_C6I = 1;					// enable C6 interrupt
//	TIM0_TSCR1_TEN = 1;				// enable timer 
}

/**********************************************************
*	init_tim0_ch7
*
*	Init TIM0 as free-running @ bus clk rate.  Config C7, C6 
*	as output compare
*
**********************************************************/
void init_tim0_ch7(void){

	TIM0_TIOS = 0x80;					// configure C7 as output compare
//	TIM0_OC7M = 0x80;					// en C7 output on compare
	TIM0_TCTL1 = 0x40;				// C7 toggle on compare
	TIM0_TSCR2_PR = 0x7;				// timer runs at bus clk rate div 128

	TIM0_TC7 = BLINK_DELAY;			// load timer channel count
	TIM0_TFLG1_C7F = 1;				// clear C7 flag
	TIM0_TIE_C7I = 1;					// enable C7 interrupt
//	TIM0_TSCR1_TEN = 1;				// enable timer 
}

/**********************************************************
*	Init_Timer1
*
*	Init TIM1 as free-running @ bus clk rate.  Config C7 
*	as output compare
*
**********************************************************/
void Init_Timer1(void){
	TIM1_TIOS = 0x80;					// setup T1C7 as output compare
	TIM1_TCTL1 &= 0x3C;				// pin is GPIO
	TIM1_TSCR2_PR = 0;				// timer runs at bus clk rate
	TIM1_TSCR1_TEN = 1;				// enable timer1 as free-running
}

/**********************************************************
*	Tim0_Dly
*
*	starts TIM0_C7 and waits for C7 flag to set, requires
*	user config TIM0 before calling
**********************************************************/
void Tim0_Dly(void){
	while(!TIM0_TFLG1_C7F); 
	TIM0_TFLG1_C7F = 1;
}

/**********************************************************
*	Delay_1ms
*
*	Uses Timer1, Ch7 to produce a 1ms Delay.  
* 	Get current TIM1 cnt and adds delay offset then waits 
*	for compare.  OVF cleared on exit from routine
*
*	Delay is based on 8MHz bus clk  
**********************************************************/
void Delay_1ms(void){
	dword t_count;
	
	t_count = TIM1_TCNT;				// get TIM1 count
	t_count += ms_Delay_Cnt;		// add offset count
	TIM1_TC7 = (word)t_count;		// load new mod value

//	TIM1_TIE_C7I = 1;					// enable T1C7 interrupt
	while(!TIM1_TFLG1_C7F);			// wait for timer flag to set
	TIM1_TFLG1_C7F = 1;				// clear overflow flag
}

/**********************************************************
*	Delay
*
*	add program Delay defined by user input.  Calls Delay_1ms()
*
*	input		- Delay in ms
**********************************************************/
void Delay(word count){
	word m;

	for(m=0; m<count; m++){
		Delay_1ms();
	}
}

/**********************************************************
*	Configure_Ports
*
*	initialize MCU port 
*
**********************************************************/
void Configure_Ports(void){
	
  	IRQCR = 0;							// IRQ responds to falling edge
  	
  /**************************
  *
  *	PORTS CONECTED TO LCD 
  *
  **************************/
  	//PULL ENABLES
  	//PUCR = 0x43;						// en PTA, PTB pull ups
  	
  	// PORT A
  	PORTA	= ALL_LOW;	   
  	DDRA	= ALL_OUTPUTS;				// PORTA is output driving low
	
  	// PORT B
  	PORTB	= ALL_LOW;	   
  	DDRB	= ALL_OUTPUTS;				// PORTB is output driving low 
	
  	// PORT H
  	PTH	= ALL_LOW;	   	 	
  	DDRH	= ALL_OUTPUTS;				// PTH is output driving low
	
  	// PORT R							// PTR[7:4] connected to LCD
  	PTR	= ALL_LOW;
  	DDRR	= ALL_OUTPUTS;				// PTR is output driving low
	
  	// PORT P
  	PTP	= ALL_LOW;	   
  	DDRP	= ALL_OUTPUTS;				// PTP is output driving low

  	// PORT T
  	PTT	= ALL_LOW;	   
  	DDRT	= ALL_OUTPUTS;				// PTT is output driving low

  /**************************
  *
  *	ALTERNATE USE PORTS 
  *
  **************************/
    // PORT S  
	PPSS 	= ALL_PULLED_DOWN;		// Configure Pull-polarity  
	PERS 	= ALL_PULLS_ON;			// Enable Pull devices  
	WOMS 	= 0x00;						// wired-or outputs disabled
	PTS 	= ALL_LOW;					// port data  
	DDRS	= 0x70;						// PTS[6:4] output, others input
	
  	// PORT U  
	PPSU 	= ALL_PULLED_DOWN;		// Configure Pull-polarity  
	PERU 	= ALL_PULLS_ON;			// Enable Pull devices  
	PTU  	= ALL_LOW;					// port data  
	DDRU 	= ALL_INPUTS ;				// port direction   
  	
  	// PORT V  
	PPSV 	= ALL_PULLED_DOWN;		// Configure Pull-polarity  
	PERV 	= ALL_PULLS_ON;			// Enable Pull devices  
	PTV   = ALL_LOW;					// port data  
	DDRV 	= ALL_INPUTS;				// port direction  

/**********************************************************
*	PORT AD SETUP
*
*	configure port as input w/ pull-ups enabled,  
*	key-wakeup enabled on PT1AD[7:4] for PBSW use
*  NOTE: to use the digital input function the ATDDIEN bit must be set  
*
*	NOTE: ATD port pull-ups are active for both digital and 
*	analog inputs !  
***********************************************************/
	PER1AD 	= ALL_PULLS_OFF;		// Port AD Pull Enable Off  
	PT1AD 	= 0x10;					// PTAD4 high, others low
	DDR1AD 	= 0x10;					// PTAD4 output, others input
	
	PIE1AD	= 0xE0;					// enable Port AD interrupts on PT1AD[7:4]
	PIF1AD	= 0xE0;					// clear spurious interrupts

	ATDDIEN	= 0xE0;					// enable PT1AD[7:5] as digital input
}


/**********************************************************
*	init_atd
*
*	setup ATD - continuous conversion on AN0 input; 8-bit result,
*	right aligned output; conversion complete interrupt enabled
*
**********************************************************/
void init_atd(void){

	ATDCTL3 = 0xA0;				//	right justify results, 4 conversions per sequence
	ATDCTL4 = 0x00;				// fATDCLK = 2.0MHz, 4 clks per sample
	ATDCTL1 = 0x1F;				// 8-bit result, discharge previous sample, input disabled
//	ATDCTL2_ASCIE = 1;			// enable conversion complete interrupt
	ATDCTL5_SCAN = 0;				// single conversion
   while(ATDSTAT0_SCF == 0);	// wait for conversion to complete
	ATDSTAT0_SCF = 0x01;			// clear conversion complete flag
}


/**********************************************************
*	read_atd_ch0
*
*	read and return current ATD, Ch0 value
**********************************************************/
byte read_atd_ch0(void){
	byte val;
	
	ATDCTL5_Cx = 0;					// single conversion
   while(ATDSTAT0_SCF == 0);		// wait for conversion to complete
	ATDSTAT0_SCF = 1;					// clear flag
	val = ATDDR0L;						// get ATD result
	return (val);						// return
}

/**********************************************************
*	read_atd_ch1
*
*	read and return current ATD, Ch0 value
**********************************************************/
byte 	read_atd_ch1(void){
	byte val;
	
	ATDCTL5_Cx = 1;					// single conversion
   while(ATDSTAT0_SCF == 0);		// wait for conversion to complete
	ATDSTAT0_SCF = 1;					// clear flag
	val = ATDDR1L;						// get ATD result
	return (val);						// return
}

/**********************************************************
*	read_atd_ch2
*
*	read and return current ATD, Ch0 value
**********************************************************/
byte 	read_atd_ch2(void){
	byte val;
	
	ATDCTL5_Cx = 2;					// single conversion
   while(ATDSTAT0_SCF == 0);		// wait for conversion to complete
	ATDSTAT0_SCF = 1;					// clear flag
	val = ATDDR2L;						// get ATD result
	return (val);						// return
}

/**********************************************************
*	read_atd_ch3
*
*	read and return current ATD, Ch0 value
**********************************************************/
byte 	read_atd_ch3(void){
	byte val;
	
	ATDCTL5_Cx = 3;					// single conversion
   while(ATDSTAT0_SCF == 0);		// wait for conversion to complete
	ATDSTAT0_SCF = 1;					// clear flag
	val = ATDDR3L;						// get ATD result
	return (val);						// return
}

/**********************************************************
*	Toggle_Led
*
*	read and return current ATD, Ch0 value
*********************************************************
void Toggle_Led(byte num){
	
	switch(num){
		case 1:  LED2 = LOFF;		// LED2 off
		case 2:	LED3 = LOFF;		// LED3 off
		case 3:	LED4 = LOFF;		// LED4 off
//		case 4:	LEDS_OFF;			// all LEDs off
	}

	switch(num){
		case 4:	LED4 ^= 1;			// toggle LED4
		case 3:	LED3 ^= 1;			// toggle LED3
		case 2:	LED2 ^= 1;			// toggle LED2
		case 1:	LED1 ^= 1;			// toggle LED1
					break;
	}
}*/

/**********************************************************
*	Get_Pot_Val
*
*	read POT and setup CAN frame to transmit data.  CAN frame
*	consists of 2 bytes - [cmd, data]
*********************************************************
void Get_Pot_Val(void){
	byte val, cmd;

	cmd = 0x30;
	val = read_atd_ch0();			// get POT value from ATD
	
	*txbuff = cmd;						// load tx buffer
	*(txbuff + 1) = val;
	tx_data_len = 0x02;				// set length
}*/


