/**********************************************************
*
*	FILE				: db_demo.c
*
*	AUTHOR			: Axiom Manufacturing
*						  Mar 2009    					     
*
*	PURPOSE			: Motor Control Demonstration for HY64 based on 
*						  MC10B8CV1 Motor Controller Block Description
*						  
**********************************************************/

#include <hidef.h>					// common defines and macros
#include <mc9s12hy64.h>				// derivative information
#include "db_demo.h"					// Dashboard Cluster Demo Board Functions
#include "cpu.h"						// cpu header file
#include "motor_drv.h"				// motor control header file
#include "lcddrv.h"					// LCD module functions
#include "lcd_demo.h"				// LCD demo functions

/**********************************************************
*	dashboard_init
*
*	Initialize Dashboard Cluster Demo board w/ HCS12HY64 installed
**********************************************************/
void dashboard_init(void){
	LCD_Init();							// init LCD 
	lcd_on();							// turn on all LCD segments
	menu_sw_st = 0;					// init menu sw state var
	Display_Off();						// all LCD segments off
	
   r_sw_st = OFF;						// init right sw status
   l_sw_st = OFF;						// init left sw status
   m_sw_st = OFF;						// init menu sw status
}


/**********************************************************
*	dashboard_demo
*
*	Initialize Dashboard Cluster Demo board w/ HCS12HY64 installed
**********************************************************/
void dashboard_demo(byte st){
	switch(st){
		case 0:	MC_zero_pointer();		// motor pointer to zero position
					Display_On();
					motor_dir = CW;					// initial motor direction CW   
					for(;;){
						MC_step_dir_all(motor_dir);		
						MC_step_all(245);		// step all motors
						motor_dir ^= 1;		// reverse direction
					}
					break;
		case 1:	MC_zero_pointer();		// motor pointer to zero position
					motor_dir = CW;			// initial motor rotation
					for(;;){
						MC_step_dir_all(motor_dir);		
						MC_step_mph_motor(245);		// move pointer to 0 position
						MC_step_rpm_motor(245);		// move pointer to 0 position
						MC_step_fuel_motor(245);	// move pointer to 0 position
						MC_step_temp_motor(245);	// move pointer to 0 position
						motor_dir ^= 1;				// reverse direction
					}
					break;
		case 2:	for(;;){
						MCPER = MC_PER_OFF;	// disable MC
						Trans_Demo();			// transmission & compass demo
					}
					break;
		case 3:	for(;;){
						Temp_Demo();			// temperature demo
					}
					break;
		case 4:	for(;;){
						Odo_Demo();				// odometer demo
					}
					break;
		case 5:	for(;;){
						Fuel_Clk_Demo();		// odometer demo
					}
					break;
	}
}


/**********************************************************
*	ignition_status
*
*	get status of ignition input
*
*	otuput:	0 - success, 1 - fail
**********************************************************/
byte ignition_status(void){
	
	if(read_atd_ch1() < 0x66) return 1;		// ignition status fail
	return 0;							// ignition status ok
}


/**********************************************************
*	ignition_off
*
*	turn off motors and motor LEDs, turn off LCD, turn off LEDs
**********************************************************/
void ignition_off(void){
	
	ign_st = 0;							// clear ignition state
	Set_Odo_Digits_Off();
	Fuel_Clk_Labels_All_Off();
	Set_ODO_Labels_All_Off();
}


/**********************************************************
*	right_turn_ctl
*
*	read and return current ATD, Ch0 value
**********************************************************/
void right_turn_ctl(void){

	if(l_sw_st){
		left_turn_ctl();				// turn on left turn LED if on
	}
	
	if(r_sw_st){
		TIM0_TSCR1_TEN = 0;			// disable timer
		TIM0_TIE_C7I = 0;				// disable timer interrupt
		TIM0_TFLG1_C7F = 1;			// clear C7 flag
		r_sw_st = 0;					// clr left sw state
	} else {
		r_sw_st = 1;					// set left sw state
		init_tim0_ch7();				// init timer
		TIM0_TSCR1_TEN = 1;			// enable timer 
	}
}

/**********************************************************
*	left_turn_ctl
*
*	read and return current ATD, Ch0 value
**********************************************************/
void left_turn_ctl(void){

	if(r_sw_st){
		right_turn_ctl();				// turn on left turn LED if on
	}
	
	if(l_sw_st){
		TIM0_TSCR1_TEN = 0;			// disable timer
		TIM0_TIE_C6I = 0;				// disable timer interrupt
		TIM0_TFLG1_C6F = 1;			// clear C6 flag
		l_sw_st = 0;					// clr left sw state
	} else {
		l_sw_st = 1;					// set left sw state
		init_tim0_ch6();				// init timer
		TIM0_TSCR1_TEN = 1;			// enable timer 
		}
}


