/**********************************************************
*
*	FILE				: hy64_isr.c
*
*	AUTHOR			: Axiom Manufacturing
*						  Mar 2009    					     
*
*	PURPOSE			: HY64 Interrupt Service Routines 
*						  
* 
**********************************************************/

#include <hidef.h>					// common defines and macros
#include <mc9s12hy64.h>				// derivative information
#include "cpu.h"						// CPU routines
#include "db_demo.h"					// demo board header file
#include "lcd_demo.h"				// LCD header file

// Global Variables 
extern byte menu_sw_st;


#pragma CODE_SEG NON_BANKED

/**********************************************************
*	tim0_c6_isr
*
*	interrupt handler for TIM0_Ch6 interrupts
**********************************************************/
void interrupt 14 tim0_c6_isr(void){
	TIM0_TFLG1_C6F = 1;				// clear C6 flag
	TIM0_TCNT = 0x0000;				// restart counter
}

/**********************************************************
*	tim0_c7_isr
*
*	interrupt handler for TIM0_Ch7 interrupts
**********************************************************/
void interrupt 15 tim0_c7_isr(void){
	TIM0_TFLG1_C7F = 1;				// clear C6 flag
	TIM0_TCNT = 0x0000;				// restart counter
}

/**********************************************************
*	sci_isr
*
*	interrupt handler for SCI module interrupts
*********************************************************
void interrupt 20 sci_isr(void){
	DisableInterrupts;
	echo_com();						// echo keybd data
	EnableInterrupts;
}
*/

/**********************************************************
*	atd_isr
*
*	interrupt handler for SCI module interrupts
**********************************************************/
void interrupt 22 atd_isr(void){
	
	byte temp;
	
	DisableInterrupts;
	ATDSTAT0_SCF = 0x01;			// clear conversion complete flag
	
	temp = ATDDR0L;
	if(temp < 0x66){				// input is too low
		ignition_off();			// call ign off routine
	}
	
	EnableInterrupts;
}


/**********************************************************
*	kbi_isr
*
*	interrupt handler for PBSW interrupt
**********************************************************/
void interrupt 24 kbi_isr(void){
	byte int_flag = 0, sw_st = 0;
	byte st1 = 0, st2 = 0, n = 0;
	
	DisableInterrupts;
	int_flag = (PIF1AD >> 4);		// capture interrupt status and shift to low nibble

//	while(~(MENU_SW)| ~(RIGHT_SW) | ~(LEFT_SW));	// wait
	
	Delay(5);							// wait for switch to debounce

	sw_st = int_flag & 0x0E;		// capture pressed sw

	switch(sw_st){
		case 2:	if(menu_sw_st == 5)	// Menu SW pressed
						menu_sw_st = 0;	// reset state count
					else menu_sw_st ++;	// incr state count
					PIF1AD = 0xF0;			// clear PBSW interrutps
					EnableInterrupts;
					dashboard_demo(menu_sw_st);
				 	break;
		case 4:	right_turn_ctl();	// Right SW pressed
				 	break;
		case 8:	left_turn_ctl();	// Left SW pressed
		default:	break;				// others
	}
	PIF1AD = 0xF0;						// clear PBSW interrutps
	EnableInterrupts;
}

/**********************************************************
*	tim1_c7_isr
*
*	interrupt handler for SCI module interrupts
**********************************************************/
void interrupt 47 tim1_c7_isr(void){
	TIM1_TFLG1_C7F = 1;				// clear overflow flag
}



#pragma CODE_SEG DEFAULT


