/**********************************************************
*
*	FILE				: motor_drv.h
*
*	AUTHOR			: Axiom Manufacturing
*						  Jan 2009    					     
*						  
*	PURPOSE			: Motor Controller header file based on 
*						  MC10B8CV1 Motor Controller Block
*						  Description
**********************************************************/

#ifndef _MOTOR_DRV_H_
#define _MOTOR_DRV_H_

#define	CW					0
#define	CCW				1			

#define	MPH_STEP_CCW	MCCC0_MCAM = LEFTALIGN;	MCCC1_MCAM = RIGHTALIGN;
#define	MPH_STEP_CW		MCCC0_MCAM = RIGHTALIGN; MCCC1_MCAM = LEFTALIGN;

#define	FUEL_STEP_CCW	MCCC2_MCAM = LEFTALIGN;	MCCC3_MCAM = RIGHTALIGN;
#define	FUEL_STEP_CW	MCCC2_MCAM = RIGHTALIGN; MCCC3_MCAM = LEFTALIGN;

#define	RPM_STEP_CCW	MCCC4_MCAM = LEFTALIGN;	MCCC5_MCAM = RIGHTALIGN;
#define	RPM_STEP_CW		MCCC4_MCAM = RIGHTALIGN; MCCC5_MCAM = LEFTALIGN;

#define	TEMP_STEP_CCW	MCCC6_MCAM = LEFTALIGN;	MCCC7_MCAM = RIGHTALIGN;
#define	TEMP_STEP_CW	MCCC6_MCAM = RIGHTALIGN; MCCC7_MCAM = LEFTALIGN;


#define	DIV1				0x00
#define	DIV2				0x01
#define	DIV4				0x02
#define	DIV8				0x03

#define	FULLBRIDGE		0x02
#define	DUALFULLBRIDGE	0x03

#define	CHANNEL_DIS		0x00
#define	LEFTALIGN		0x01
#define	RIGHTALIGN		0x02
#define	CENTERALIGN		0x03

#define	CHANDELAY0		0x00
#define	CHANDELAY1		0x01
#define	CHANDELAY2		0x02
#define	CHANDELAY3		0x03

#define	MC_PERIOD		0x07FF
#define 	MC_PER_OFF		0x0000;	

#define	MAX_STEP_CNT	0x0140	// max 320 steps

extern word num_steps;
extern byte motor_dir;				// motor direction


/************* Function Prototypes ***********************/
void MC_init(void);					// initialize Motor Controller
void MC_zero_pointer(void);		// move pointer to "0" position
void MC_motor_demo(void);			// Motor 1 Demo


void MC_motor_leds(byte st);
void MC_step_all(word step);		// step all motors CCW for # of steps indicated
void MC_step_mph_motor(word step);	// step motor for # of steps input
void MC_step_rpm_motor(word step);
void MC_step_fuel_motor(word step);
void MC_step_temp_motor(word step);

void MC_step_dir_all(byte dir);
void MC_step_dir(byte motor, byte dir);

#endif	// _MOTOR_DRV_H_